Package: WikidataQueryServiceR
Title: API Client Library for 'Wikidata Query Service'
Version: 1.0.0
Date: 2020-06-16
Authors@R: c(
    person("Mikhail", "Popov", email = "mikhail@wikimedia.org",
           role = c("aut", "cre"), comment = "@bearloga on Twitter"),
    person("Wikimedia Foundation", role = "cph")
    )
Description: An API client for the 'Wikidata Query Service'
    <https://query.wikidata.org/>.
Depends: R (>= 3.1.2)
Imports: httr (>= 1.2.1), dplyr (>= 1.0.0), jsonlite (>= 1.2),
        WikipediR (>= 1.5.0), ratelimitr (>= 0.4.1), purrr (>= 0.3.4),
        readr (>= 1.3.1), rex (>= 1.2.0)
Suggests: testthat (>= 2.3.0), lintr (>= 2.0.1)
URL: https://github.com/bearloga/WikidataQueryServiceR
BugReports: https://github.com/bearloga/WikidataQueryServiceR/issues
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-06-16 20:01:17 UTC; mpopov
Author: Mikhail Popov [aut, cre] (@bearloga on Twitter),
  Wikimedia Foundation [cph]
Maintainer: Mikhail Popov <mikhail@wikimedia.org>
Repository: CRAN
Date/Publication: 2020-06-16 20:10:02 UTC
